// See the Electron documentation for details on how to use preload scripts:
// https://www.electronjs.org/docs/latest/tutorial/process-model#preload-scripts

import { contextBridge, ipcRenderer } from 'electron';

contextBridge.exposeInMainWorld('electronAPI', {
  // 检查URL是否可用
  checkUrlAvailable: (url: string) => ipcRenderer.invoke('check-url-available', url),
  
  // 设置 sessionStorage
  setSessionStorage: (key: string, value: string) => {
    window.sessionStorage.setItem(key, value);
  },
  
  // 获取 sessionStorage
  getSessionStorage: (key: string) => {
    return window.sessionStorage.getItem(key);
  },
  
  // 删除 sessionStorage
  removeSessionStorage: (key: string) => {
    window.sessionStorage.removeItem(key);
  },
  
  // 清空 sessionStorage
  clearSessionStorage: () => {
    window.sessionStorage.clear();
  }
});
